summaryrefslogtreecommitdiff
path: root/distro/packages/base.scm
diff options
context:
space:
mode:
Diffstat (limited to 'distro/packages/base.scm')
-rw-r--r--distro/packages/base.scm11
1 files changed, 8 insertions, 3 deletions
diff --git a/distro/packages/base.scm b/distro/packages/base.scm
index ed33d61d35..4b176301d6 100644
--- a/distro/packages/base.scm
+++ b/distro/packages/base.scm
@@ -320,10 +320,12 @@ that it is possible to use Make to build and install the program.")
`(("patch/new-dtags" ,(search-patch "binutils-ld-new-dtags.patch"))))
(arguments
`(#:patches (list (assoc-ref %build-inputs "patch/new-dtags"))
+ #:configure-flags '(;; Add `-static-libgcc' to not retain a dependency
+ ;; on GCC when bootstrapping.
+ "LDFLAGS=-static-libgcc"
- ;; Add `-static-libgcc' to not retain a dependency on GCC when
- ;; bootstrapping.
- #:configure-flags '("LDFLAGS=-static-libgcc")))
+ ;; Don't search under /usr/lib & co.
+ "--with-lib-path=/no-ld-lib-path")))
(synopsis "GNU Binutils, tools for manipulating binaries (linker,
assembler, etc.)")
@@ -358,6 +360,9 @@ BFD (Binary File Descriptor) library, `gprof', `nm', `strip', etc.")
`("--enable-plugin"
"--enable-languages=c,c++"
"--disable-multilib"
+
+ "--with-local-prefix=/no-gcc-local-prefix"
+
,(let ((libc (assoc-ref %build-inputs "libc")))
(if libc
(string-append "--with-native-system-header-dir=" libc